@@ -10,7 +10,7 @@
 #ifndef LIBDEFINE_H
 #define LIBDEFINE_H
 
-#include "libconfig.h"
+//#include "libghemicalconfig2.h"
 
 /*################################################################################################*/
 
@@ -22,6 +22,10 @@
 
 #define NOT_DEFINED -1
 
+/// The value zero is reserved for unregistered glnames (GUI stuff).
+
+#define GLNAME_UNREGISTERED 0
+
 /*################################################################################################*/
 
 // some additional macros here...
