@@ -10,7 +10,7 @@
 #ifndef MODEL_H
 #define MODEL_H
 
-#include "libconfig.h"
+//#include "libghemicalconfig2.h"
 
 class model;
 class crd_set;
@@ -142,7 +142,8 @@ class model
 	
 	friend class setup_druid;	// this is for ghemical!!! // needs access to current_setup...	// for BBB
 	friend class setup_dialog;	// this is for ghemical!!! // needs access to current_setup...	// for HEAD
-	friend class ribbon;		// this is for ghemical!!!
+friend class ribbon;		// this is for ghemical!!!
+friend class ssc_view;		// this is for ghemical!!!
 	
 	friend void CopyCRD(model *, engine *, i32u);
 	friend void CopyCRD(engine *, model *, i32u);
