@@ -10,7 +10,7 @@
 #ifndef NOTICE_H
 #define NOTICE_H
 
-#include "libconfig.h"
+#include "libghemicalconfig2.h"
 
 /* added by Robert Williams for Compaq cxx, alpha 11/28/01 */
 #define __USE_STD_IOSTREAM
