@@ -127,6 +127,18 @@ sequencebuilder::sequencebuilder(chn_info::chn_type ct, char * filename)
 		main_vector.push_back(newatm);
 	}
 	
+	while (file.peek() != 'C') file.getline(buffer, sizeof(buffer));
+	file.getline(buffer, sizeof(buffer));
+	
+	while (file.peek() != 'E')
+	{
+		sb_data_atm newatm; file >> newatm;
+		while (file.peek() != '(') file.get();
+		newatm.tr = new typerule(& file, & cout);
+		file.getline(buffer, sizeof(buffer));
+		conn_vector.push_back(newatm);
+	}
+	
 	// read descriptions about the chain initiation...
 	
 	while (file.peek() != 'H') file.getline(buffer, sizeof(buffer));
@@ -153,13 +165,13 @@ sequencebuilder::sequencebuilder(chn_info::chn_type ct, char * filename)
 	
 	// read the default modifications for residues...
 	
-	while (file.peek() != 'B') file.getline(buffer, sizeof(buffer));
+	while (file.peek() != 'B') file.getline(buffer, sizeof(buffer));					// default...
 	file.getline(buffer, sizeof(buffer)); mod[0] = new sb_data_res; mod[0]->ReadModification(file);
 	
-	while (file.peek() != 'H') file.getline(buffer, sizeof(buffer));
+	while (file.peek() != 'H') file.getline(buffer, sizeof(buffer));					// secondary!
 	file.getline(buffer, sizeof(buffer)); mod[1] = new sb_data_res; mod[1]->ReadModification(file);
 	
-	while (file.peek() != 'T') file.getline(buffer, sizeof(buffer));
+	while (file.peek() != 'T') file.getline(buffer, sizeof(buffer));					// primary!
 	file.getline(buffer, sizeof(buffer)); mod[2] = new sb_data_res; mod[2]->ReadModification(file);
 	
 	// read descriptions for the residues...
@@ -208,6 +220,9 @@ void sequencebuilder::Build(model * mdl, char * sequence, f64 * tor)
 	
 	for (i32u n1 = 0;n1 < strlen(sequence);n1++)
 	{
+		bool first_res = (n1 == 0);
+		bool last_res = (n1 == (strlen(sequence) - 1));
+		
 		for (i32u n2 = 0;n2 < main_vector.size();n2++)
 		{
 			atom * prev[3];
@@ -227,16 +242,42 @@ void sequencebuilder::Build(model * mdl, char * sequence, f64 * tor)
 			
 			ref_vector.push_back(& mdl->atom_list.back());
 			
-			if (n1 || n2)
+			if (!first_res || n2 != 0)
 			{
 				bond newbond(prev[0], & mdl->atom_list.back(), main_vector[n2].bt[0]);
 				mdl->AddBond(newbond);
 			}
 		}
 		
-		if (!n1) Build(mdl, mod[1], tor);
-		else if (n1 == (strlen(sequence) - 1)) Build(mdl, mod[2], tor);
-		else Build(mdl, mod[0], tor);
+		if (!last_res)
+		{
+			for (i32u n2 = 0;n2 < conn_vector.size();n2++)
+			{
+				atom * prev[3];
+				f64 ic[3]; fGL crd[3];
+				for (i32s n3 = 0;n3 < 3;n3++)
+				{
+					i32s n4 = 0; while (id_vector[n4] != conn_vector[n2].prev[n3]) n4++;
+					prev[n3] = ref_vector[n4]; ic[n3] = conn_vector[n2].ic1[n3];
+				}
+				
+				if (conn_vector[n2].ic2 > -1) ic[2] += tor[conn_vector[n2].ic2];
+				Convert(prev, ic, crd);
+				
+				id_vector.push_back(conn_vector[n2].id[0]);
+				atom newatom(conn_vector[n2].el, crd, mdl->cs_vector.size());
+				mdl->AddAtom(newatom);
+				
+				ref_vector.push_back(& mdl->atom_list.back());
+				
+				bond newbond(prev[0], & mdl->atom_list.back(), conn_vector[n2].bt[0]);
+				mdl->AddBond(newbond);
+			}
+		}
+		
+		if (last_res) Build(mdl, mod[2], tor);		// primary!
+		else if (first_res) Build(mdl, mod[1], tor);	// secondary!
+		else Build(mdl, mod[0], tor);			// default...
 		
 		i32u res = 0;
 		while (residue_vector[res].symbol != sequence[n1])
@@ -353,22 +394,23 @@ cout << "nmol = " << mdl->nmol << endl;
 			}
 			
 			vector<char> sequence;
-			bool head_blocked = !head_vector[0].Check(mdl, path_vector[n2].front(), 1);	// what exactly is this???
-			bool tail_blocked = !tail_vector[0].Check(mdl, path_vector[n2].back(), 1);	// what exactly is this???
+bool head_blocked = !head_vector[0].Check(mdl, path_vector[n2].front(), 1);	// what exactly is this???
+bool tail_blocked = !tail_vector[0].Check(mdl, path_vector[n2].back(), 1);	// what exactly is this???
 			
 			i32u acount = 0;	// atom counter
 			i32u rcount = 0;	// residue counter
 			
 			while (acount < path_vector[n2].size())
 			{
-				i32u rsize = main_vector.size();
-				
 				// rsize is the residue size (how many atoms it will chop away from the
 				// path_vector). we use it to determine whether we have reached the last
 				// residue, and to increment acount.
 				
 				bool is_first = !head_blocked && !rcount;
-				bool is_last = !tail_blocked && (acount + rsize >= path_vector[n2].size());
+				bool is_last = !tail_blocked && (acount + main_vector.size() + conn_vector.size() >= path_vector[n2].size());
+				
+				i32u rsize = main_vector.size();
+				if (!is_last) rsize += conn_vector.size();
 				
 				// now we start identifying the residues.
 				
@@ -377,10 +419,10 @@ cout << "nmol = " << mdl->nmol << endl;
 				// there may not be any missing atoms, and the closest match is
 				// the one with largest number of correct atoms identified.
 				
-				// some problems with the blocked head/tail residues???
+// some problems with the blocked head/tail residues???
 				
 				i32s tmp1[2] = { NOT_DEFINED, NOT_DEFINED };
-				for (i32s n4 = 0;n4 < (i32s) residue_vector.size();n4++)	// n3???
+				for (i32s n4 = 0;n4 < (i32s) residue_vector.size();n4++)
 				{
 					vector<sb_tdata> tdata;
 					BuildTemplate(tdata, n4, is_first, is_last);
@@ -390,6 +432,15 @@ cout << "nmol = " << mdl->nmol << endl;
 						tdata[n5].ref = path_vector[n2][acount + n5];
 					}
 					
+					if (!is_last)
+					{
+						const int mvsz = main_vector.size();
+						for (i32s n5 = 0;n5 < (i32s) conn_vector.size();n5++)
+						{
+							tdata[mvsz + n5].ref = path_vector[n2][acount + mvsz + n5];
+						}
+					}
+					
 					bool result = CheckTemplate(tdata, 0);
 					if (result && (tmp1[0] == NOT_DEFINED || ((i32s) tdata.size()) > tmp1[1]))
 					{
@@ -427,6 +478,15 @@ cout << "nmol = " << mdl->nmol << endl;
 						tdata[n4].ref = path_vector[n2][acount + n4];
 					}
 					
+					if (!is_last)
+					{
+						const int mvsz = main_vector.size();
+						for (i32s n5 = 0;n5 < (i32s) conn_vector.size();n5++)
+						{
+							tdata[mvsz + n5].ref = path_vector[n2][acount + mvsz + n5];
+						}
+					}
+					
 					CheckTemplate(tdata, 0);
 					for (i32s n4 = 0;n4 < (i32s) tdata.size();n4++)
 					{
@@ -621,10 +681,20 @@ void sequencebuilder::Convert(atom * prev[], f64 * ic, fGL * crd)
 
 void sequencebuilder::FindPath(model * mdl, atom * ref1, atom * ref2, i32u index)
 {
-	if (index >= main_vector.size()) index = 0;
+	if (index >= main_vector.size() + conn_vector.size()) index = 0;
 	
-	if (ref1->el.GetAtomicNumber() != main_vector[index].el.GetAtomicNumber()) return;
-	if (!main_vector[index].tr->Check(mdl, ref1, 0)) return;
+	if (index < main_vector.size())
+	{
+		if (ref1->el.GetAtomicNumber() != main_vector[index].el.GetAtomicNumber()) return;
+		if (!main_vector[index].tr->Check(mdl, ref1, 0)) return;
+	}
+	else
+	{
+		i32u index2 = index - main_vector.size();
+		
+		if (ref1->el.GetAtomicNumber() != conn_vector[index2].el.GetAtomicNumber()) return;
+		if (!conn_vector[index2].tr->Check(mdl, ref1, 0)) return;
+	}
 	
 	temporary_vector.push_back(ref1);
 	
@@ -652,10 +722,11 @@ void sequencebuilder::FindPath(model * mdl, atom * ref1, atom * ref2, i32u index
 void sequencebuilder::BuildTemplate(vector<sb_tdata> & tdata, i32s res, bool is_first, bool is_last)
 {
 	BuildTemplate(tdata, main_vector);
+	if (!is_last) BuildTemplate(tdata, conn_vector);
 	
-	if (is_first) BuildTemplate(tdata, mod[1]->atm_vector);
-	else if (is_last) BuildTemplate(tdata, mod[2]->atm_vector);
-	else BuildTemplate(tdata, mod[0]->atm_vector);
+	if (is_last) BuildTemplate(tdata, mod[2]->atm_vector);		// primary!
+	else if (is_first) BuildTemplate(tdata, mod[1]->atm_vector);	// secondary!
+	else BuildTemplate(tdata, mod[0]->atm_vector);			// default...
 	
 	BuildTemplate(tdata, residue_vector[res].atm_vector);
 }
@@ -765,7 +836,6 @@ bool sequencebuilder::CheckTemplate(vector<sb_tdata> & tdata, i32s flag)
 		}
 		
 		if (!next_permutation(tmpv3.begin(), tmpv3.end())) break;
-//		if (!next_permutation(tmpv3.begin(), tmpv3.end(), less<i32s>())) break;	// for WIN32 ???
 	}
 	
 	// none of those combinations matched -> the template doesn't fit -> FALSE!!!
