@@ -10,7 +10,7 @@
 #ifndef TAB_MM_DEFAULT_H
 #define TAB_MM_DEFAULT_H
 
-#include "libconfig.h"
+//#include "libghemicalconfig2.h"
 
 struct default_at;		// atomtype
 
